@@ -15,13 +15,12 @@ descendent.sets <- function(node, s, G.s.obs, topo) {
   desc <- desc[!vapply(desc, is.null, logical(1))]
   n.desc <- length(desc)
   if (n.desc > 0) {
-    desc.pow <- powerset(1:n.desc, nonempty = TRUE)
+    desc.pow <- powerset(1:n.desc)[-1]
     n.sets <- 2^n.desc - 1
     D <- vector(mode = "list", length = n.sets)
     for (i in 1:n.sets) {
       D[[i]] <- Reduce(union, desc[desc.pow[[i]]])
     }
-    # cat("Descendant sets of ", s, " not containing ", node, " are" , as.character(unique(D)), "\n")
     return(unique(D))
   }
   return(list())
