@@ -1,4 +1,3 @@
-is.prefix <-
-function(prefixes, sq) {
+is.prefix <- function(prefixes, sq) {
   any(sapply(prefixes, function(x) identical(sq[1:length(x)], x)))
 }
\ No newline at end of file
