@@ -1,4 +1,4 @@
-simplify <- function(P, topo, G.adj, G, G.obs) {
+simplify <- function(P, topo, G.unobs, G, G.obs) {
   j <- 0
   while (j < length(P$sumset)) {
     P.orig <- P
@@ -14,7 +14,7 @@ simplify <- function(P, topo, G.adj, G, G.obs) {
     J <- character()
     D <- character()
     if (i > 1) {
-      irrel <- irrelevant(P$children[1:(i-1)], P$sumset[j], P$sumset, G.adj)
+      irrel <- irrelevant(P$children[1:(i-1)], P$sumset[j], P$sumset, G.unobs)
       irl.len <- length(irrel)
       if (irl.len > 0) {
         i <- i - irl.len
@@ -26,7 +26,7 @@ simplify <- function(P, topo, G.adj, G, G.obs) {
     M <- topo[!(topo %in% vars)]
     O <- topo[(topo %in% vars)]
     while (k <= i) {
-      joint <- join(J, D, P$children[[k]]$var, P$children[[k]]$cond, P$sumset[j], M, O, G.adj, G, G.obs, topo)
+      joint <- join(J, D, P$children[[k]]$var, P$children[[k]]$cond, P$sumset[j], M, O, G.unobs, G, G.obs, topo)
       if (length(joint[[1]]) <= length(J)) {
         J <- character()
         D <- character()
@@ -48,7 +48,6 @@ simplify <- function(P, topo, G.adj, G, G.obs) {
       P <- factorize(J, D, P, topo, i)
       S <- P$sumset[j]
       P$sumset <- P$sumset[-j]
-      if (irl.len > 0) P$children <- c(terms, P$children)
       if (length(R.var) > 0) {
         P.cancel <- cancel(P, R.var, R.cond, S)
         if (identical(P.cancel, P)) P <- P.orig
@@ -57,6 +56,7 @@ simplify <- function(P, topo, G.adj, G, G.obs) {
           j <- 0
         } 
       } else j <- 0
+      if (irl.len > 0) P$children <- c(terms, P$children)
     } else P <- P.orig
   }
   return(P)
